# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bakerstreet/bakerstreet.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='bakerstreet/bakerstreet.proto',
  package='com.appknox.bakerstreet',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1d\x62\x61kerstreet/bakerstreet.proto\x12\x17\x63om.appknox.bakerstreet\"\x17\n\x07Message\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\t\"1\n\x04\x41pps\x12)\n\x03\x41pp\x18\x01 \x03(\x0b\x32\x1c.com.appknox.bakerstreet.App\"\x13\n\x03\x41pp\x12\x0c\n\x04Name\x18\x01 \x01(\t\"\x89\x01\n\x06\x44\x65vice\x12\x0c\n\x04Uuid\x18\x01 \x01(\t\x12\x10\n\x08IsTablet\x18\x02 \x01(\x08\x12\x10\n\x08Platform\x18\x03 \x01(\x05\x12\x17\n\x0fPlatformVersion\x18\x04 \x01(\t\x12\x17\n\x0f\x43puArchitecture\x18\x05 \x01(\t\x12\r\n\x05Model\x18\x06 \x01(\t\x12\x0c\n\x04Name\x18\x07 \x01(\t\"-\n\x07\x46inding\x12\r\n\x05Title\x18\x01 \x01(\t\x12\x13\n\x0b\x44\x65scription\x18\x02 \x01(\t\"\x19\n\nInstallReq\x12\x0b\n\x03URL\x18\x01 \x01(\t\"s\n\x0e\x43onfigProxyReq\x12\n\n\x02IP\x18\x01 \x01(\t\x12\x0c\n\x04Port\x18\x02 \x01(\t\x12\r\n\x05Hosts\x18\x03 \x03(\t\x12\x11\n\tChainHost\x18\x04 \x01(\t\x12\x11\n\tChainPort\x18\x05 \x01(\t\x12\x12\n\nCaptureAll\x18\x06 \x01(\x08\"\x1e\n\x0c\x43leanOptions\x12\x0e\n\x06\x44ryRun\x18\x01 \x01(\x08\"\x07\n\x05\x45mpty2\x88\x07\n\x08Moriarty\x12J\n\x04\x45\x63ho\x12 .com.appknox.bakerstreet.Message\x1a .com.appknox.bakerstreet.Message\x12K\n\tLaunchApp\x12\x1c.com.appknox.bakerstreet.App\x1a .com.appknox.bakerstreet.Message\x12N\n\nClearProxy\x12\x1e.com.appknox.bakerstreet.Empty\x1a .com.appknox.bakerstreet.Message\x12O\n\x0bHealthCheck\x12\x1e.com.appknox.bakerstreet.Empty\x1a .com.appknox.bakerstreet.Message\x12O\n\rRemovePackage\x12\x1c.com.appknox.bakerstreet.App\x1a .com.appknox.bakerstreet.Message\x12W\n\x0eInstallPackage\x12#.com.appknox.bakerstreet.InstallReq\x1a .com.appknox.bakerstreet.Message\x12[\n\x0e\x43onfigureProxy\x12\'.com.appknox.bakerstreet.ConfigProxyReq\x1a .com.appknox.bakerstreet.Message\x12Q\n\x0f\x43onfigureGadget\x12\x1c.com.appknox.bakerstreet.App\x1a .com.appknox.bakerstreet.Message\x12P\n\x05\x43lean\x12%.com.appknox.bakerstreet.CleanOptions\x1a .com.appknox.bakerstreet.Message\x12G\n\x04Info\x12\x1e.com.appknox.bakerstreet.Empty\x1a\x1f.com.appknox.bakerstreet.Device\x12M\n\x0cListPackages\x12\x1e.com.appknox.bakerstreet.Empty\x1a\x1d.com.appknox.bakerstreet.Appsb\x06proto3'
)




_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='com.appknox.bakerstreet.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Data', full_name='com.appknox.bakerstreet.Message.Data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=81,
)


_APPS = _descriptor.Descriptor(
  name='Apps',
  full_name='com.appknox.bakerstreet.Apps',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='App', full_name='com.appknox.bakerstreet.Apps.App', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=132,
)


_APP = _descriptor.Descriptor(
  name='App',
  full_name='com.appknox.bakerstreet.App',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Name', full_name='com.appknox.bakerstreet.App.Name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=153,
)


_DEVICE = _descriptor.Descriptor(
  name='Device',
  full_name='com.appknox.bakerstreet.Device',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Uuid', full_name='com.appknox.bakerstreet.Device.Uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='IsTablet', full_name='com.appknox.bakerstreet.Device.IsTablet', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Platform', full_name='com.appknox.bakerstreet.Device.Platform', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='PlatformVersion', full_name='com.appknox.bakerstreet.Device.PlatformVersion', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='CpuArchitecture', full_name='com.appknox.bakerstreet.Device.CpuArchitecture', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Model', full_name='com.appknox.bakerstreet.Device.Model', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Name', full_name='com.appknox.bakerstreet.Device.Name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=156,
  serialized_end=293,
)


_FINDING = _descriptor.Descriptor(
  name='Finding',
  full_name='com.appknox.bakerstreet.Finding',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Title', full_name='com.appknox.bakerstreet.Finding.Title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Description', full_name='com.appknox.bakerstreet.Finding.Description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=295,
  serialized_end=340,
)


_INSTALLREQ = _descriptor.Descriptor(
  name='InstallReq',
  full_name='com.appknox.bakerstreet.InstallReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='URL', full_name='com.appknox.bakerstreet.InstallReq.URL', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=342,
  serialized_end=367,
)


_CONFIGPROXYREQ = _descriptor.Descriptor(
  name='ConfigProxyReq',
  full_name='com.appknox.bakerstreet.ConfigProxyReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='IP', full_name='com.appknox.bakerstreet.ConfigProxyReq.IP', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Port', full_name='com.appknox.bakerstreet.ConfigProxyReq.Port', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Hosts', full_name='com.appknox.bakerstreet.ConfigProxyReq.Hosts', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ChainHost', full_name='com.appknox.bakerstreet.ConfigProxyReq.ChainHost', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ChainPort', full_name='com.appknox.bakerstreet.ConfigProxyReq.ChainPort', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='CaptureAll', full_name='com.appknox.bakerstreet.ConfigProxyReq.CaptureAll', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=369,
  serialized_end=484,
)


_CLEANOPTIONS = _descriptor.Descriptor(
  name='CleanOptions',
  full_name='com.appknox.bakerstreet.CleanOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='DryRun', full_name='com.appknox.bakerstreet.CleanOptions.DryRun', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=486,
  serialized_end=516,
)


_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='com.appknox.bakerstreet.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=518,
  serialized_end=525,
)

_APPS.fields_by_name['App'].message_type = _APP
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
DESCRIPTOR.message_types_by_name['Apps'] = _APPS
DESCRIPTOR.message_types_by_name['App'] = _APP
DESCRIPTOR.message_types_by_name['Device'] = _DEVICE
DESCRIPTOR.message_types_by_name['Finding'] = _FINDING
DESCRIPTOR.message_types_by_name['InstallReq'] = _INSTALLREQ
DESCRIPTOR.message_types_by_name['ConfigProxyReq'] = _CONFIGPROXYREQ
DESCRIPTOR.message_types_by_name['CleanOptions'] = _CLEANOPTIONS
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'bakerstreet.bakerstreet_pb2'
  # @@protoc_insertion_point(class_scope:com.appknox.bakerstreet.Message)
  })
_sym_db.RegisterMessage(Message)

Apps = _reflection.GeneratedProtocolMessageType('Apps', (_message.Message,), {
  'DESCRIPTOR' : _APPS,
  '__module__' : 'bakerstreet.bakerstreet_pb2'
  # @@protoc_insertion_point(class_scope:com.appknox.bakerstreet.Apps)
  })
_sym_db.RegisterMessage(Apps)

App = _reflection.GeneratedProtocolMessageType('App', (_message.Message,), {
  'DESCRIPTOR' : _APP,
  '__module__' : 'bakerstreet.bakerstreet_pb2'
  # @@protoc_insertion_point(class_scope:com.appknox.bakerstreet.App)
  })
_sym_db.RegisterMessage(App)

Device = _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), {
  'DESCRIPTOR' : _DEVICE,
  '__module__' : 'bakerstreet.bakerstreet_pb2'
  # @@protoc_insertion_point(class_scope:com.appknox.bakerstreet.Device)
  })
_sym_db.RegisterMessage(Device)

Finding = _reflection.GeneratedProtocolMessageType('Finding', (_message.Message,), {
  'DESCRIPTOR' : _FINDING,
  '__module__' : 'bakerstreet.bakerstreet_pb2'
  # @@protoc_insertion_point(class_scope:com.appknox.bakerstreet.Finding)
  })
_sym_db.RegisterMessage(Finding)

InstallReq = _reflection.GeneratedProtocolMessageType('InstallReq', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLREQ,
  '__module__' : 'bakerstreet.bakerstreet_pb2'
  # @@protoc_insertion_point(class_scope:com.appknox.bakerstreet.InstallReq)
  })
_sym_db.RegisterMessage(InstallReq)

ConfigProxyReq = _reflection.GeneratedProtocolMessageType('ConfigProxyReq', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGPROXYREQ,
  '__module__' : 'bakerstreet.bakerstreet_pb2'
  # @@protoc_insertion_point(class_scope:com.appknox.bakerstreet.ConfigProxyReq)
  })
_sym_db.RegisterMessage(ConfigProxyReq)

CleanOptions = _reflection.GeneratedProtocolMessageType('CleanOptions', (_message.Message,), {
  'DESCRIPTOR' : _CLEANOPTIONS,
  '__module__' : 'bakerstreet.bakerstreet_pb2'
  # @@protoc_insertion_point(class_scope:com.appknox.bakerstreet.CleanOptions)
  })
_sym_db.RegisterMessage(CleanOptions)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'bakerstreet.bakerstreet_pb2'
  # @@protoc_insertion_point(class_scope:com.appknox.bakerstreet.Empty)
  })
_sym_db.RegisterMessage(Empty)



_MORIARTY = _descriptor.ServiceDescriptor(
  name='Moriarty',
  full_name='com.appknox.bakerstreet.Moriarty',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=528,
  serialized_end=1432,
  methods=[
  _descriptor.MethodDescriptor(
    name='Echo',
    full_name='com.appknox.bakerstreet.Moriarty.Echo',
    index=0,
    containing_service=None,
    input_type=_MESSAGE,
    output_type=_MESSAGE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LaunchApp',
    full_name='com.appknox.bakerstreet.Moriarty.LaunchApp',
    index=1,
    containing_service=None,
    input_type=_APP,
    output_type=_MESSAGE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ClearProxy',
    full_name='com.appknox.bakerstreet.Moriarty.ClearProxy',
    index=2,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_MESSAGE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='HealthCheck',
    full_name='com.appknox.bakerstreet.Moriarty.HealthCheck',
    index=3,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_MESSAGE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemovePackage',
    full_name='com.appknox.bakerstreet.Moriarty.RemovePackage',
    index=4,
    containing_service=None,
    input_type=_APP,
    output_type=_MESSAGE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InstallPackage',
    full_name='com.appknox.bakerstreet.Moriarty.InstallPackage',
    index=5,
    containing_service=None,
    input_type=_INSTALLREQ,
    output_type=_MESSAGE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ConfigureProxy',
    full_name='com.appknox.bakerstreet.Moriarty.ConfigureProxy',
    index=6,
    containing_service=None,
    input_type=_CONFIGPROXYREQ,
    output_type=_MESSAGE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ConfigureGadget',
    full_name='com.appknox.bakerstreet.Moriarty.ConfigureGadget',
    index=7,
    containing_service=None,
    input_type=_APP,
    output_type=_MESSAGE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Clean',
    full_name='com.appknox.bakerstreet.Moriarty.Clean',
    index=8,
    containing_service=None,
    input_type=_CLEANOPTIONS,
    output_type=_MESSAGE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Info',
    full_name='com.appknox.bakerstreet.Moriarty.Info',
    index=9,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_DEVICE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListPackages',
    full_name='com.appknox.bakerstreet.Moriarty.ListPackages',
    index=10,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_APPS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MORIARTY)

DESCRIPTOR.services_by_name['Moriarty'] = _MORIARTY

# @@protoc_insertion_point(module_scope)
